@@ -140,6 +140,9 @@ class SDSSLogger(logging.Logger):
         self.fh = None
         self.log_filename = None
 
+        # A header that precedes every message.
+        self.header = ''
+
         # Catches exceptions
         sys.excepthook = self._catch_exceptions
 
@@ -191,7 +194,7 @@ class SDSSLogger(logging.Logger):
     def save_log(self, path):
         shutil.copyfile(self.log_filename, os.path.expanduser(path))
 
-    def start_file_logger(self, path, log_level=logging.DEBUG):
+    def start_file_logger(self, path, log_level=logging.DEBUG, mode='a', rotating=True):
         """Start file logging."""
 
         log_file_path = os.path.expanduser(path)
@@ -202,10 +205,14 @@ class SDSSLogger(logging.Logger):
             if not os.path.exists(logdir):
                 os.makedirs(logdir)
 
-            self.fh = TimedRotatingFileHandler(
-                str(log_file_path), when='midnight', utc=True)
-
-            self.fh.suffix = '%Y-%m-%d_%H:%M:%S'
+            if rotating:
+                self.fh = TimedRotatingFileHandler(str(log_file_path),
+                                                   mode=mode,
+                                                   when='midnight',
+                                                   utc=True)
+                self.fh.suffix = '%Y-%m-%d_%H:%M:%S'
+            else:
+                self.fh = logging.FileHandler(str(log_file_path), mode=mode)
 
         except (IOError, OSError) as ee:
 
@@ -227,6 +234,9 @@ class SDSSLogger(logging.Logger):
     def handle(self, record):
         """Handles a record but first stores it."""
 
+        if hasattr(self, 'header') and self.header is not None:
+            record.msg = self.header + record.msg
+
         if record.levelno == logging.ERROR:
             self._last_error = record.getMessage()
 
